# coding=utf-8
"""Kodi Plugin for www.serienjunkies.de"""
import sys
from urllib import urlencode
from urlparse import parse_qsl
import requests
import xbmcgui  # pylint: disable=E0401
import xbmcplugin  # pylint: disable=E0401
import xbmcaddon  # pylint: disable=E0401
from bs4 import BeautifulSoup
import os


URL = sys.argv[0]
HANDLE = int(sys.argv[1])
FALLBACK = os.path.join(xbmcaddon.Addon().getAddonInfo('path'), 'resources', 'fallback.jpg')


def get_url(**kwargs):
    """
    Create a URL for calling the plugin recursively from the given set of keyword arguments.
    """
    return '{0}?{1}'.format(URL, urlencode(kwargs))


def check_resource(url):
    """
    Check availability of online resources
    """
    res = requests.get(url)
    if res.status_code == 200:
        return url
    return FALLBACK


def list_tv_shows():
    """
    List tv shows
    """
    xbmcplugin.setPluginCategory(HANDLE, "Deutschland")
    xbmcplugin.setContent(HANDLE, 'videos')

    response = requests.get("https://www.serienjunkies.de/docs/serienplaner.html")
    soup = BeautifulSoup(response.text, "html.parser")
    elements = soup.find_all("div", class_="tablerow")
    for element in elements:
        try:
            label = element.find_all("a")[0].text.encode('utf-8')
            transmitter = element.find_all("a")[-1].get("title")
            if not transmitter:
                transmitter = element.find_all("img")[-1].get("title")
            list_item = xbmcgui.ListItem(label=label)
            tv_show_id = element.find_all("a")[0].get("href").split("/")[1]
            list_item.setArt({
                'poster': check_resource("https://s-cdn.serienjunkies.de/n/" + tv_show_id + ".jpg"),
                'fanart': check_resource("https://s-cdn.serienjunkies.de/n/" + tv_show_id + ".jpg")
            })
            appointment = element.find_all("div")[1].find_all("div")[1].text.encode('utf-8')
            plot = transmitter + ": " + appointment
            list_item.setInfo('video', {'plot': plot})
            xbmcplugin.addDirectoryItem(
                HANDLE,
                get_url(action='show_tv_show_info', header=label, message=plot), list_item
            )
        except:
            continue
    xbmcplugin.endOfDirectory(HANDLE)


def show_tv_show_info(header="", message=""):
    xbmcgui.Dialog().ok(header, message)


def router(paramstring):
    """
    Router function that calls other functions depending on the provided paramstring
    """
    params = dict(parse_qsl(paramstring))
    if params:
        if params['action'] == 'show_tv_show_info':
            show_tv_show_info(params['header'], params['message'])
        else:
            raise ValueError('Invalid paramstring: {0}!'.format(paramstring))
    else:
        list_tv_shows()


if __name__ == '__main__':
    router(sys.argv[2][1:])
